@@ -866,3 +866,11 @@ start_test sort "sort complains on file that doesn't contain valid UTF-8 for mer
     assert_file_size 2 0 ../test_tmp/stdout.txt &&
     assert_file_content_pattern 3 '^\.\./test_fixtures/test_sort_invalid_utf8.txt: stream' ../test_tmp/stderr.txt
 end_test
+
+start_test sort "sort sorts lines for bug of sorting character boundary"
+    "../$RSUBOX" sort -k 1.2 ../test_fixtures/test_bug_sort1.txt > ../test_tmp/stdout.txt 2> ../test_tmp/stderr.txt
+
+    assert 1 [ 0 = "$?" ] &&
+    assert_compare_files 2 ../test_fixtures/test_bug_sort1_sorted.txt ../test_tmp/stdout.txt &&
+    assert_file_size 3 0 ../test_tmp/stderr.txt
+end_test
